@@ -174,7 +174,7 @@ public class MAPIProp {
             s.append(" name=").append(getName());
         s.append(" ID=").append(TNEFUtils.getConstName(this.getClass(),"PR_",getID()));
         if (getLength() == 0)
-            s.append(" value=").append(String.valueOf((Object)null));
+            s.append(" value=").append((Object)null);
         else if (getLength() == 1)
             s.append(" value=").append(getValues()[0]);
         else
@@ -659,9 +659,63 @@ public class MAPIProp {
         PR_BUSINESS_ADDRESS_POSTAL_CODE         = PR_POSTAL_CODE,
         PR_BUSINESS_ADDRESS_POST_OFFICE_BOX     = PR_POST_OFFICE_BOX;
         
-        
     /**
-     * MAPI property name guid constant.
+     * Exchange property ID constant.
+     */
+    public static final int
+        PR_MTS_ID                                       = 0x0047,
+        PR_MTS_REPORT_ID                                = 0x0047,
+        PR_MESSAGE_SIZE_EXTENDED                        = 0x0E08,
+        PR_MEMBER_ENTRYID                               = 0x0FFF,
+        PR_OWA_URL                                      = 0x10F1,
+        PR_DISABLE_FULL_FIDELITY                        = 0x10F2,
+        PR_P1_CONTENT                                   = 0x1100,
+        PR_P1_CONTENT_TYPE                              = 0x1101,
+        PR_EMS_AB_DISPLAY_NAME_PRINTABLE                = 0x39FF,
+        PR_PREVIEW_UNREAD                               = 0x3FD8,
+        PR_PREVIEW                                      = 0x3FD9,
+        PR_ABSTRACT                                     = 0x3FDA,
+        PR_DL_REPORT_FLAGS                              = 0x3FDB,
+        PR_BILATERAL_INFO                               = 0x3FDC,
+        PR_MSG_BODY_ID                                  = 0x3FDD,
+        PR_INTERNET_CPID                                = 0x3FDE,
+        PR_AUTO_RESPONSE_SUPPRESS                       = 0x3FDF,
+        PR_ACL_TABLE                                    = 0x3FE0,
+        PR_ACL_DATA                                     = 0x3FE0,
+        PR_RULES_TABLE                                  = 0x3FE1,
+        PR_RULES_DATA                                   = 0x3FE1,
+        PR_FOLDER_DESIGN_FLAGS                          = 0x3FE2,
+        PR_DELEGATED_BY_RULE                            = 0x3FE3,
+        PR_DESIGN_IN_PROGRESS                           = 0x3FE4,
+        PR_SECURE_ORIGINATION                           = 0x3FE5,
+        PR_PUBLISH_IN_ADDRESS_BOOK                      = 0x3FE6,
+        PR_RESOLVE_METHOD                               = 0x3FE7,
+        PR_ADDRESS_BOOK_DISPLAY_NAME                    = 0x3FE8,
+        PR_EFORMS_LOCALE_ID                             = 0x3FE9,
+        PR_HAS_DAMS                                     = 0x3FEA,
+        PR_DEFERRED_SEND_NUMBER                         = 0x3FEB,
+        PR_DEFERRED_SEND_UNITS                          = 0x3FEC,
+        PR_EXPIRY_NUMBER                                = 0x3FED,
+        PR_EXPIRY_UNITS                                 = 0x3FEE,
+        PR_DEFERRED_SEND_TIME                           = 0x3FEF,
+        PR_CONFLICT_ENTRYID                             = 0x3FF0,
+        PR_MESSAGE_LOCALE_ID                            = 0x3FF1,
+        PR_RULE_TRIGGER_HISTORY                         = 0x3FF2,
+        PR_MOVE_TO_STORE_ENTRYID                        = 0x3FF3,
+        PR_MOVE_TO_FOLDER_ENTRYID                       = 0x3FF4,
+        PR_STORAGE_QUOTA_LIMIT                          = 0x3FF5,
+        PR_EXCESS_STORAGE_USED                          = 0x3FF6,
+        PR_SVR_GENERATING_QUOTA_MSG                     = 0x3FF7,
+        PR_CREATOR_NAME                                 = 0x3FF8,
+        PR_CREATOR_ENTRYID                              = 0x3FF9,
+        PR_LAST_MODIFIER_NAME                           = 0x3FFA,
+        PR_LAST_MODIFIER_ENTRYID                        = 0x3FFB,
+        PR_REPLY_RECIPIENT_SMTP_PROXIES                 = 0x3FFC,
+        PR_MESSAGE_CODEPAGE                             = 0x3FFD,
+        PR_EXTENDED_ACL_DATA                            = 0x3FFE;
+    
+    /**
+     * MAPI property name GUID constant.
      */
     public static final GUID
         // Used in appointment item properties. Message class: IPM.Appointment
