@@ -65,6 +65,8 @@ public class MAPIPropName {
             this.rawLength += length;
         } else if (type == MNID_ID) {
             this.ID = data.readU32();
+        } else {
+            throw new IOException("invalid type: " + type);
         }
         this.rawLength = (int)(data.getPosition() - startOffest);
     }
@@ -155,9 +157,8 @@ public class MAPIPropName {
         MAPIPropName p = (MAPIPropName)o;
         return
             this.type == p.type
-            && this.type == MNID_ID ? this.ID == p.ID : true
-            && this.guid.equals(p.guid)
-            && this.type == MNID_STRING ? this.name.equals(p.name) : true;
+            && (this.type == MNID_ID ? this.ID == p.ID : this.name.equals(p.name))
+            && this.guid.equals(p.guid);
     }
     
     /**
