@@ -35,15 +35,18 @@ public class MAPIValue {
     RawInputStream rawData;
 
     /**
-     * Constructs a MAPIValue containing given values.
+     * Constructs a MAPIValue containing a given value.
      *
      * @param type the value type
      * @param data the TNEF stream containing the value
      * @param length the length of the value data (in bytes)
+     * @throws IllegalArgumentException if type is invalid
      * @throws IOException if the stream end is reached,
      *         or if an I/O error occurs
      */
     public MAPIValue(int type, RawInputStream data, int length) throws IOException {
+        if ((type & MAPIProp.MV_FLAG) != 0)
+            throw new IllegalArgumentException("multivalue is not allowed in single MAPIValue");
         this.type = type;
         this.rawData = new RawInputStream(data, 0, length);
         data.skip(length);
@@ -157,7 +160,8 @@ public class MAPIValue {
                 if (ris.getLength() == 8) {
                     long time = ris.readU64();
                     time = time / 10 / 1000; // to milliseconds
-                    time = time - 1000L*60L*60L*24L*(365L*369L+89L); // milliseconds between 1/1/1601 and 1/1/1970 (including 89 leap year days)
+                    // subtract milliseconds between 1/1/1601 and 1/1/1970 (including 89 leap year days)
+                    time = time - 1000L*60L*60L*24L*(365L*369L+89L);
                     o = new Date(time);
                 }
                 break;
@@ -174,7 +178,7 @@ public class MAPIValue {
                 break;
 
             case MAPIProp.PT_CLSID:
-                // CLSID - 20 bytes
+                // CLSID - 16 bytes
                 o = ris.toByteArray();
                 break;
 
